@@ -545,10 +545,12 @@ class FluxAgent:
         p.mkdir(parents=True, exist_ok=True)
 
         plugins = [
-            f.rstrip(".py") for f in os.listdir(p) if os.path.isfile(os.path.join(p, f))
+            f.rstrip(".py")
+            for f in p.iterdir()
+            if not f.is_dir() and not str(f).endswith("runner.py")
         ]
 
-        log.debug(f"Plugins available: {plugins}")
+        log.info(f"Plugins available: {plugins}")
 
         for f in plugins:
             importlib.invalidate_caches()
